using Attribute;
using Common;
using Dto;
using Vo;
using Enums;
using Filters;
using Infrastructure;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using Middleware;
using Model;
using Services;
using Model.Base;
using Base;

namespace Controllers
{
    /// <summary>
    /// FileUpdateInfo)Controller
    /// </summary>
    // [Route("FileUpdateInfo")]
    // [ApiExplorerSettings(GroupName = "FileUpdateInfo")]
    public class FileUpdateInfoController : BaseController
    {
        /// <summary>
        /// api分组接口
        /// </summary>
        private readonly IFileUpdateInfoService _FileUpdateInfoService;


        public FileUpdateInfoController(IFileUpdateInfoService FileUpdateInfoService)
        {
            _FileUpdateInfoService = FileUpdateInfoService;

        }

        /// <summary>
        /// 资源文件更新信息列表
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>资源文件更新信息列表</returns>
        [HttpGet]
        [Route("/v1/api/FileUpdateInfo/list")]
        public IActionResult List([FromQuery] FileUpdateInfoListDto parm, [FromQuery] PagerInfo page)
        {
            var response = _FileUpdateInfoService.List(parm, page);
            return SUCCESS(response);
        }




        /// <summary>
        /// 资源文件更新信息详情
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>资源文件更新信息详情</returns>
        [HttpGet]
        [Route("/v1/api/FileUpdateInfo/query")]
        public IActionResult Query([FromQuery] FileUpdateInfoQueryDto parm)
        {
            var response = _FileUpdateInfoService.Queryable()
                .First(x => x.id == parm.id)
                .Adapt<FileUpdateInfoQueryVo>() ?? new FileUpdateInfoQueryVo();
            return SUCCESS(response);
        }




        /// <summary>
        /// 资源文件更新信息添加
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>资源文件更新信息添加</returns>
        [HttpPost]
        [Route("/v1/api/FileUpdateInfo/add")]
        public IActionResult Add([FromBody] FileUpdateInfoAddDto parm)
        {
            var modal = parm.Adapt<FileUpdateInfo>().ToCreate(HttpContext);
            var response = _FileUpdateInfoService.Add(modal);
            return SUCCESS(response);
        }




        /// <summary>
        /// 资源文件更新信息修改
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>资源文件更新信息修改</returns>
        [HttpPut]
        [Route("/v1/api/FileUpdateInfo/update")]
        public IActionResult Update([FromBody] FileUpdateInfoUpdateDto parm)
        {
            var modal = parm.Adapt<FileUpdateInfo>().ToUpdate(HttpContext);
            var response = _FileUpdateInfoService.Update(modal, true);
            return SUCCESS(response);
        }




        /// <summary>
        /// 资源文件更新信息删除
        /// </summary>
        /// <param name="Id">ID</param>
        /// <returns>资源文件更新信息删除</returns>
        [HttpDelete]
        [Route("/v1/api/FileUpdateInfo/delete/{id}")]
        public IActionResult Delete(int id)
        {
            var response = _FileUpdateInfoService.Delete(id);
            return SUCCESS(response);
        }




        /// <summary>
        /// 资源文件更新信息刷新文件
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>资源文件更新信息刷新文件</returns>
        [HttpGet]
        [Route("/v1/api/FileUpdateInfo/updateFile")]
        public IActionResult UpdateFile([FromQuery] FileUpdateInfoUpdateFileDto parm)
        {
            _FileUpdateInfoService.UpdateFile(parm);
            return SUCCESS("ok");
        }




        /// <summary>
        /// 资源文件更新信息更新版本号
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>资源文件更新信息更新版本号</returns>
        [HttpPut]
        [Route("/v1/api/FileUpdateInfo/upVersion")]
        public IActionResult UpVersion([FromBody] FileUpdateInfoUpVersionDto parm)
        {
            var modal = _FileUpdateInfoService.GetFirst(m => m.id == parm.id);
            modal.versionNum += 1;
            var response = _FileUpdateInfoService.Update(modal, true);
            return SUCCESS(response);
        }






    }
}