using Attribute;
using Common;
using Dto;
using Vo;
using Enums;
using Filters;
using Infrastructure;
using Infrastructure.Model;
using Mapster;
using Microsoft.AspNetCore.Mvc;
using Middleware;
using Model;
using Services;
using Model.Base;

namespace Controllers
{
    /// <summary>
    /// PageUpdateInfo)Controller
    /// </summary>
    // [Route("PageUpdateInfo")]
    // [ApiExplorerSettings(GroupName = "PageUpdateInfo")]
    public class PageUpdateInfoController : BaseController
    {
        private readonly IPageUpdateInfoService _PageUpdateInfoService;
        private readonly IAppBottomNavsService _AppBottomNavsService;
        private readonly IFileUpdateInfoService _FileUpdateInfoService;


        public PageUpdateInfoController(IPageUpdateInfoService PageUpdateInfoService, IAppBottomNavsService AppBottomNavsService, IFileUpdateInfoService FileUpdateInfoService)
        {
            _PageUpdateInfoService = PageUpdateInfoService;
            _AppBottomNavsService = AppBottomNavsService;
            _FileUpdateInfoService = FileUpdateInfoService;
        }

        /// <summary>
        /// 页面模板更新信息列表
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息列表</returns>
        [HttpGet]
        [Route("/v1/api/PageUpdateInfo/list")]
        public IActionResult List([FromQuery] PageUpdateInfoListDto parm, [FromQuery] PagerInfo page)
        {
            var response = _PageUpdateInfoService.List(parm, page);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息详情
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息详情</returns>
        [HttpGet]
        [Route("/v1/api/PageUpdateInfo/query")]
        public IActionResult Query([FromQuery] PageUpdateInfoQueryDto parm)
        {
            var response = _PageUpdateInfoService.Queryable()
                .First(x => x.id == parm.id)
                .Adapt<PageUpdateInfoQueryVo>() ?? new PageUpdateInfoQueryVo();
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息添加
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息添加</returns>
        [HttpPost]
        [Route("/v1/api/PageUpdateInfo/add")]
        public IActionResult Add([FromBody] PageUpdateInfoAddDto parm)
        {
            var modal = parm.Adapt<PageUpdateInfo>().ToCreate(HttpContext);
            var response = _PageUpdateInfoService.Add(modal);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息修改
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息修改</returns>
        [HttpPut]
        [Route("/v1/api/PageUpdateInfo/update")]
        public IActionResult Update([FromBody] PageUpdateInfoUpdateDto parm)
        {
            var modal = parm.Adapt<PageUpdateInfo>().ToUpdate(HttpContext);
            var response = _PageUpdateInfoService.Update(modal, true);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息删除
        /// </summary>
        /// <param name="Id">ID</param>
        /// <returns>页面模板更新信息删除</returns>
        [HttpDelete]
        [Route("/v1/api/PageUpdateInfo/delete/{id}")]
        public IActionResult Delete(int id)
        {
            var response = _PageUpdateInfoService.Delete(id);
            return SUCCESS(response);
        }




        /// <summary>
        /// 页面模板更新信息刷新文件
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息刷新文件</returns>
        [HttpGet]
        [Route("/v1/api/PageUpdateInfo/updateTemplate")]
        public IActionResult UpdateTemplate([FromQuery] PageUpdateInfoUpdateTemplateDto parm)
        {
            _PageUpdateInfoService.UpdateTemplate(parm);
            return SUCCESS("ok");
        }




        /// <summary>
        /// 页面模板更新信息更新版本号码
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>页面模板更新信息更新版本号码</returns>
        [HttpPut]
        [Route("/v1/api/PageUpdateInfo/upVersion")]
        public IActionResult UpVersion([FromBody] PageUpdateInfoUpVersionDto parm)
        {
            var modal = _PageUpdateInfoService.GetFirst(m => m.id == parm.id);
            modal.moduleVersion += 1;
            var response = _PageUpdateInfoService.Update(modal, true);
            return SUCCESS(response);
        }





        /// <summary>
        /// 生成APP配置文件
        /// </summary>
        /// <param name="parm">请求参数</param>
        /// <returns>生成APP配置文件</returns>
        [HttpGet]
        [Route("/noauth/SystemSet/makeAppInitData")]
        public string makeAppInitData([FromQuery] MakeAppInitDataDto parm)
        {
            string AppInfoList = _AppBottomNavsService.makeAppInitData(parm.kind, parm.appVersion);
            string FileInfoList = _FileUpdateInfoService.makeAppInitData(parm.kind, parm.appVersion);
            string PageInfoList = _PageUpdateInfoService.makeAppInitData(parm.kind, parm.appVersion);
            return AppInfoList + "#cut#" + FileInfoList + "#cut#" + PageInfoList;
        }


        [Route("/noauth/test")]
        public string test()
        {
            string str = "[{\"title\":\"首页\",\"normalIcon\":\"/static/images/tab-icon1-no@3x.png\",\"selectIcon\":\"/static/images/tab-icon1-active1@3x.png\",\"normalTextColor\":\"999999\",\"selectTextColor\":\"333333\",\"pageName\":\"index1\",\"NoUrlMessage\":\"\",\"backgroudColor\":\"FFFFFF\",\"statusBarColor\":\"true\",\"showTitle\":true},{\"title\":\"工作台\",\"normalIcon\":\"/static/images/tab-icon2-no@3x.png\",\"selectIcon\":\"/static/images/tab-icon2-active1@3x.png\",\"normalTextColor\":\"999999\",\"selectTextColor\":\"333333\",\"pageName\":\"work-center1\",\"NoUrlMessage\":null,\"backgroudColor\":\"FFFFFF\",\"statusBarColor\":\"true\",\"showTitle\":true},{\"title\":\"消息\",\"normalIcon\":\"/static/images/tab-icon3-no@3x.png\",\"selectIcon\":\"/static/images/tab-icon3-active1@3x.png\",\"normalTextColor\":\"999999\",\"selectTextColor\":\"333333\",\"pageName\":\"notice-center1\",\"NoUrlMessage\":null,\"backgroudColor\":\"FFFFFF\",\"statusBarColor\":\"true\",\"showTitle\":false},{\"title\":\"我的\",\"normalIcon\":\"/static/images/tab-icon4-no@3x.png\",\"selectIcon\":\"/static/images/tab-icon4-active1@3x.png\",\"normalTextColor\":\"999999\",\"selectTextColor\":\"333333\",\"pageName\":\"user-center1\",\"NoUrlMessage\":null,\"backgroudColor\":\"FFFFFF\",\"statusBarColor\":\"true\",\"showTitle\":true}]";
            return Dbconn.Encrypt3DES(str, "*ga34|^7");
        }



    }
}